@@ -2,7 +2,7 @@
 # copyright notices and license terms.
 from trytond.pool import Pool
 
-from . import batch, journal, move, party
+from . import batch, invoice, journal, move, party
 
 __all__ = ['register']
 
@@ -19,6 +19,11 @@ def register():
         move.Move,
         move.MoveLine,
         module='account_batch', type_='model')
+    Pool.register(
+        batch.BatchLineTaxCash,
+        invoice.Invoice,
+        depends=['account_tax_cash'],
+        module='account_batch', type_='model')
     Pool.register(
         batch.CancelBatchLines,
         batch.OpenBatchJournal,
