@@ -27,7 +27,7 @@ class Move(metaclass=PoolMeta):
 
     @classmethod
     def _get_origin(cls):
-        return super(Move, cls)._get_origin() + ['account.batch.line']
+        return super()._get_origin() + ['account.batch.line']
 
 
 class MoveLine(metaclass=PoolMeta):
@@ -35,6 +35,11 @@ class MoveLine(metaclass=PoolMeta):
 
     reference = fields.Char('Reference')
 
+    @classmethod
+    def _get_origin(cls):
+        return super()._get_origin() + ['account.batch.line']
+
+
     def check_account(self):
         '''
         We must override completely, because this check is not extensible
